 # Mutiny PowerShell script to check a text file is readable & create critical event if count exceeds trigger value
# Used as an early warning for ransomware infection as the file will become encrypted and the string will not match
#
# Version 1.0 (3-06-2021)
#
# Author: Lawrence Freeman based on a script by Mark Smith


### Enter customised values in this section
# Agent Name
$agentName = "MutPSA_RansomCheck"

# Capturing date if used in file name - may need amending to required format
$logdate = date -uFormat %Y%m%d

# Path to file (you can edit this as required you may choose to use other common file locations like shares etc.)
$FilePath = "c:\AATestFile.txt"

# String to search for in file
$TextPattern = "Simple"

# Number of text strings found in file which triggers critical event in Mutiny
$CountTrigger = "1"

# Text to include in the event detail if a match is found (could include instructions to resolve)
$EventDetail = "File is readable"


### Do not modify these sections
# Date settings for output to Mutiny
clear
$dateString = date -uFormat %Y%m%d%H%M%S

# Set the folders for the Agent results
if([System.IntPtr]::Size -eq 4) {
    $agentResultsFolder = $($(get-itemproperty -path hklm:/software/mutiny/snmpagent/testdir).pathname)
} else {
    $agentResultsFolder = $($(get-itemproperty -path hklm:/software/Wow6432Node/mutiny/snmpagent/testdir).pathname)
}

# Agent output - results file
$resultsFile = $agentResultsFolder+$agentName+".txt"

# Var Setup
$furtherDetails = "";
$details = "";
$globalStatus = 3;

# Search File for Text String
$FileContent = Get-Content $FilePath
$Matches = Select-String -InputObject $FileContent -Pattern $TextPattern -AllMatches
$StringCount = $Matches.Matches.Count

# If number of string matches is below count trigger
if($StringCount -lt $CountTrigger) {
    $globalStatus = 0;
    $details = "Sample file is not readable (check for RANSOMWARE) or file has been deleted (replace).";
}

# If number of string matches is equal to or greater than count trigger
if($StringCount -ge $CountTrigger) {
    $globalStatus = 1;
    $details = $EventDetail;
}

# Give some further details to the user.
$furtherDetails = "The file $FilePath was tested";

# Write results out
$outString ="$agentName`|$globalStatus`|$dateString`|$details`|$furtherDetails`|"
$outString | out-file -encoding ascii $resultsFile

exit 
